@@ -30,7 +30,7 @@ class PacketDirection(IntEnum):
 class Packet(Serializable, RequiredParamsABCMixin):
     """Base class for all packets"""
 
-    _REQUIRRED_CLASS_VARS: ClassVar[Sequence[str]] = ["PACKET_ID", "GAME_STATE"]
+    _REQUIRED_CLASS_VARS: ClassVar[Sequence[str]] = ["PACKET_ID", "GAME_STATE"]
     _REQUIRED_CLASS_VARS_NO_MRO: ClassVar[Sequence[str]] = ["__slots__"]
 
     __slots__ = ()
@@ -42,6 +42,10 @@ class Packet(Serializable, RequiredParamsABCMixin):
 class ServerBoundPacket(Packet):
     """Packet bound to a server (Client -> Server)."""
 
+    __slots__ = ()
+
 
 class ClientBoundPacket(Packet):
     """Packet bound to a client (Server -> Client)."""
+
+    __slots__ = ()
